define(
//begin v1.x content
{
	"field-tue-relative+-1": "el martes pasado",
	"field-year": "año",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "este miércoles",
	"field-wed-relative+1": "el próximo miércoles",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minuto",
	"field-month-narrow-relative+-1": "el mes pasado",
	"field-tue-narrow-relative+0": "este MA",
	"field-tue-narrow-relative+1": "el próximo MA",
	"field-day-short-relative+-1": "ayer",
	"field-thu-short-relative+0": "este jue.",
	"field-day-relative+0": "hoy",
	"field-day-short-relative+-2": "anteayer",
	"field-thu-short-relative+1": "el próximo jue.",
	"field-day-relative+1": "mañana",
	"field-week-narrow-relative+0": "esta sem.",
	"field-day-relative+2": "pasado mañana",
	"field-week-narrow-relative+1": "próx. sem.",
	"field-wed-narrow-relative+-1": "el MI pasado",
	"field-year-narrow": "a",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "este año",
	"field-tue-relative+0": "este martes",
	"field-year-narrow-relative+1": "el próximo año",
	"field-tue-relative+1": "el próximo martes",
	"field-weekdayOfMonth": "día de la semana del mes",
	"field-second-short": "s",
	"dateFormatItem-MMMd": "d-M",
	"field-weekdayOfMonth-narrow": "día de sem. de mes",
	"field-week-relative+0": "esta semana",
	"field-month-relative+0": "este mes",
	"field-week-relative+1": "la próxima semana",
	"field-month-relative+1": "el próximo mes",
	"field-sun-narrow-relative+0": "este DO",
	"field-mon-short-relative+0": "este lun.",
	"field-sun-narrow-relative+1": "el próximo DO",
	"field-mon-short-relative+1": "el próximo lun.",
	"field-second-relative+0": "ahora",
	"dateFormatItem-yyyyQQQ": "QQQ y",
	"field-weekOfMonth": "semana del mes",
	"field-month-short": "m",
	"dateFormatItem-GyMMMEd": "E, d-M-y",
	"dateFormatItem-yyyyMd": "d-M-y",
	"field-day": "día",
	"field-dayOfYear-short": "día del a",
	"field-year-relative+-1": "el año pasado",
	"field-sat-short-relative+-1": "el sáb. pasado",
	"field-hour-relative+0": "esta hora",
	"dateFormatItem-yyyyMEd": "E, d-M-y",
	"field-wed-relative+-1": "el miércoles pasado",
	"field-sat-narrow-relative+-1": "el SA pasado",
	"field-second": "segundo",
	"dateFormat-long": "d-M-y",
	"dateFormatItem-GyMMMd": "d-M-y",
	"field-quarter": "trimestre",
	"field-week-short": "sem.",
	"field-day-narrow-relative+0": "hoy",
	"field-day-narrow-relative+1": "mañana",
	"field-day-narrow-relative+2": "pasado mañana",
	"field-tue-short-relative+0": "este mar.",
	"field-tue-short-relative+1": "el próximo mar.",
	"field-month-short-relative+-1": "el mes pasado",
	"field-mon-relative+-1": "el lunes pasado",
	"dateFormatItem-GyMMM": "M-y",
	"field-month": "mes",
	"field-day-narrow": "d",
	"dateFormatItem-MMM": "L",
	"field-minute-short": "min",
	"field-dayperiod": "a. m./p. m.",
	"field-sat-short-relative+0": "este sáb.",
	"field-sat-short-relative+1": "el próximo sáb.",
	"dateFormat-medium": "d-M-y",
	"dateFormatItem-yyyyMMMM": "M-y",
	"dateFormatItem-yyyyM": "M-y",
	"field-second-narrow": "s",
	"field-mon-relative+0": "este lunes",
	"field-mon-relative+1": "el próximo lunes",
	"field-day-narrow-relative+-1": "ayer",
	"field-year-short": "a",
	"field-day-narrow-relative+-2": "anteayer",
	"field-quarter-relative+-1": "el trimestre pasado",
	"dateFormatItem-yyyyMMMd": "d-M-y",
	"field-dayperiod-narrow": "a. m./p. m.",
	"field-week-narrow-relative+-1": "sem. ant.",
	"field-dayOfYear": "día del año",
	"field-sat-relative+-1": "el sábado pasado",
	"dateFormatItem-Md": "d-M",
	"field-hour": "hora",
	"dateFormat-full": "EEEE, d-M-y",
	"field-month-relative+-1": "el mes pasado",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "trim.",
	"field-sat-narrow-relative+0": "este SA",
	"field-fri-relative+0": "este viernes",
	"field-sat-narrow-relative+1": "el próximo SA",
	"field-fri-relative+1": "el próximo viernes",
	"field-month-narrow-relative+0": "este mes",
	"field-month-narrow-relative+1": "el próximo mes",
	"field-sun-short-relative+0": "este dom.",
	"field-sun-short-relative+1": "el próximo dom.",
	"field-week-relative+-1": "la semana pasada",
	"field-quarter-relative+0": "este trimestre",
	"field-minute-relative+0": "este minuto",
	"field-quarter-relative+1": "el próximo trimestre",
	"field-wed-short-relative+-1": "el mié. pasado",
	"dateFormat-short": "d-M-y",
	"field-year-narrow-relative+-1": "el año pasado",
	"field-thu-short-relative+-1": "el jue. pasado",
	"dateFormatItem-yyyyMMMEd": "E, d-M-y",
	"field-mon-narrow-relative+-1": "el LU pasado",
	"field-thu-narrow-relative+-1": "el JU pasado",
	"field-tue-narrow-relative+-1": "el MA pasado",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "sem. de mes",
	"dateFormatItem-yyyy": "y",
	"field-wed-short-relative+0": "este mié.",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "el próximo mié.",
	"field-sun-relative+-1": "el domingo pasado",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "día de la semana",
	"field-day-short-relative+0": "hoy",
	"field-day-short-relative+1": "mañana",
	"field-sat-relative+0": "este sábado",
	"dateFormatItem-h": "hh a",
	"field-day-short-relative+2": "pasado mañana",
	"field-sat-relative+1": "el próximo sábado",
	"field-week-short-relative+0": "esta sem.",
	"field-week-short-relative+1": "próx. sem.",
	"field-dayOfYear-narrow": "día del a",
	"field-month-short-relative+0": "este mes",
	"field-month-short-relative+1": "el próximo mes",
	"field-weekdayOfMonth-short": "día de sem. de mes",
	"dateFormatItem-MEd": "E, d-M",
	"field-zone-narrow": "zona",
	"dateFormatItem-y": "y",
	"field-thu-narrow-relative+0": "este JU",
	"field-sun-narrow-relative+-1": "el DO pasado",
	"field-mon-short-relative+-1": "el lun. pasado",
	"field-thu-narrow-relative+1": "el próximo JU",
	"field-thu-relative+0": "este jueves",
	"field-thu-relative+1": "el próximo jueves",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-fri-short-relative+-1": "el vie. pasado",
	"field-thu-relative+-1": "el jueves pasado",
	"field-week": "semana",
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "este MI",
	"field-wed-narrow-relative+1": "el próximo MI",
	"field-year-short-relative+0": "este año",
	"dateFormatItem-yyyyMMM": "M-y",
	"field-dayperiod-short": "a. m./p. m.",
	"field-year-short-relative+1": "el próximo año",
	"field-fri-short-relative+0": "este vie.",
	"field-fri-short-relative+1": "el próximo vie.",
	"field-week-short-relative+-1": "sem. ant.",
	"dateFormatItem-yyyyQQQQ": "QQQQ y",
	"field-hour-short": "h",
	"field-zone-short": "zona",
	"field-month-narrow": "m",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "el VI pasado",
	"field-year-relative+0": "este año",
	"field-year-relative+1": "el próximo año",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "el viernes pasado",
	"field-tue-short-relative+-1": "el mar. pasado",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "este LU",
	"field-mon-narrow-relative+1": "el próximo LU",
	"field-year-short-relative+-1": "el año pasado",
	"field-zone": "zona horaria",
	"dateFormatItem-MMMEd": "E d-M",
	"field-weekOfMonth-narrow": "sem. de mes",
	"field-weekday-narrow": "día de sem.",
	"field-quarter-narrow": "trim.",
	"field-sun-short-relative+-1": "el dom. pasado",
	"field-day-relative+-1": "ayer",
	"field-day-relative+-2": "anteayer",
	"field-weekday-short": "día de sem.",
	"field-sun-relative+0": "este domingo",
	"field-sun-relative+1": "el próximo domingo",
	"dateFormatItem-Gy": "y",
	"field-day-short": "d",
	"field-week-narrow": "sem.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "este VI",
	"field-fri-narrow-relative+1": "el próximo VI"
}
//end v1.x content
);